@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2008-2022 Statnet Commons
+#  Copyright 2008-2023 Statnet Commons
 ################################################################################
 
 stopifnot_dynamic <- function(nw, ..., dynamic=FALSE, .netseries.OK=FALSE){
@@ -29,7 +29,15 @@ stopifnot_dynamic <- function(nw, ..., dynamic=FALSE, .netseries.OK=FALSE){
 #'   old-style `formation` model.
 #'
 #' @usage
-#' # binary: Form(formula)
+#' # binary: Form(
+#' #           formula,
+#' #           lm = ~1,
+#' #           subset = TRUE,
+#' #           weights = 1,
+#' #           contrasts = NULL,
+#' #           offset = 0,
+#' #           label = NULL
+#' #         )
 #' @template ergmTerm-formula
 #'
 #' @template ergmTerm-general
@@ -85,7 +93,15 @@ InitErgmTerm..union.lt.net<-function(nw, arglist, ...) {
 #'   signs of the coefficients are negated.
 #'
 #' @usage
-#' # binary: Persist(formula)
+#' # binary: Persist(
+#' #           formula,
+#' #           lm = ~1,
+#' #           subset = TRUE,
+#' #           weights = 1,
+#' #           contrasts = NULL,
+#' #           offset = 0,
+#' #           label = NULL
+#' #         )
 #' @template ergmTerm-formula
 #'
 #' @template ergmTerm-general
@@ -111,6 +127,28 @@ InitErgmTerm..union.lt.net<-function(nw, arglist, ...) {
                list(emptynwstats=NULL)))
 }
 
+### TODO: Export this from ergm then remove from tergm.
+ergm_rename_terms <- function(model, namewrap){
+  for(i in seq_along(model$terms)){
+    model$terms[[i]]$coef.names <- namewrap(model$terms[[i]]$coef.names)
+    if(!is.null(model$terms[[i]]$params)) names(model$terms[[i]]$params) <- namewrap(names(model$terms[[i]]$params))
+  }
+  model
+}
+
+`InitErgmTerm.Cross (dynamic)` <- function(nw, arglist,  ...) {
+  stopifnot_dynamic(nw, .netseries.OK=TRUE, ...)
+  a <- check.ErgmTerm(nw, arglist,
+                      varnames = c("formula"),
+                      vartypes = c("formula"),
+                      defaultvalues = list(NULL),
+                      required = c(TRUE))
+
+  ergm_model(a$formula, nw, ..., terms.only=TRUE) %>%
+    ergm_rename_terms(function(x) paste0("Cross~", x))
+}
+
+
 #' @templateVar name Diss
 #' @title The Dissolution Operator Term
 #' @description The Dissolution Operator Term
@@ -123,7 +161,15 @@ InitErgmTerm..union.lt.net<-function(nw, arglist, ...) {
 #'   coefficient for `Diss()` operator means more dissolution.
 #'
 #' @usage
-#' # binary: Diss(formula)
+#' # binary: Diss(
+#' #           formula,
+#' #           lm = ~1,
+#' #           subset = TRUE,
+#' #           weights = 1,
+#' #           contrasts = NULL,
+#' #           offset = 0,
+#' #           label = NULL
+#' #         )
 #' @template ergmTerm-formula
 #'
 #' @template ergmTerm-general
@@ -172,7 +218,15 @@ InitErgmTerm..intersect.lt.net<-function(nw, arglist, ...) {
 #'   by taking the dyads that have changed between time steps.
 #'
 #' @usage
-#' # binary: Change(formula)
+#' # binary: Change(
+#' #           formula,
+#' #           lm = ~1,
+#' #           subset = TRUE,
+#' #           weights = 1,
+#' #           contrasts = NULL,
+#' #           offset = 0,
+#' #           label = NULL
+#' #         )
 #' @template ergmTerm-formula
 #'
 #' @template ergmTerm-general
