@@ -5,10 +5,10 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2008-2022 Statnet Commons
+#  Copyright 2008-2023 Statnet Commons
 ################################################################################
-tergm.CMLE <- function(formula, times, ..., control) {
-  nw <- eval_lhs.formula(formula)
+tergm.CMLE <- function(formula, times, ..., control, basis) {
+  nw <- basis
 
   if(!is(nw, "tergm_NetSeries")){
     if(inherits(nw, "network.list") || (is.list(nw) && !is.network(nw) && is.network(nw[[1]]))){
@@ -19,10 +19,10 @@ tergm.CMLE <- function(formula, times, ..., control) {
       stop("Unsupported specification for the network series. See help for ",sQuote("NetSeries")," for arguments.")
     }
 
-    formula <- nonsimp_update.formula(formula, NetSeries~., from.new="NetSeries")
+    nw <- NetSeries
   }
 
-  fit <- ergm(formula, ..., control=control$CMLE.ergm)
+  fit <- ergm(formula, ..., control=control$CMLE.ergm, basis = nw)
   class(fit) <- c("tergm_CMLE", "tergm", class(fit))
   fit
 }
